Market Data Scraper and Analysis Tool
This script is designed to scrape market data from yahoo finance api, count base indicators, and visualize the results using plots

![Zrzut ekranu 2024-09-11 193357](https://github.com/user-attachments/assets/af8e5a11-0db9-4d3f-8af1-b4d875409225)
